@@ -1,16 +1,32 @@
 //go:build openbsd || solaris
-// +build openbsd solaris
 
 package local
 
 import (
 	"fmt"
+	"os"
 	"syscall"
 	"time"
 
 	"github.com/rclone/rclone/fs"
 )
 
+// Read the time specified from the os.FileInfo
+func readTime(t timeType, fi os.FileInfo) time.Time {
+	stat, ok := fi.Sys().(*syscall.Stat_t)
+	if !ok {
+		fs.Debugf(nil, "didn't return Stat_t as expected")
+		return fi.ModTime()
+	}
+	switch t {
+	case aTime:
+		return time.Unix(stat.Atim.Unix())
+	case cTime:
+		return time.Unix(stat.Ctim.Unix())
+	}
+	return fi.ModTime()
+}
+
 // Read the metadata from the file into metadata where possible
 func (o *Object) readMetadataFromFile(m *fs.Metadata) (err error) {
 	info, err := o.fs.lstat(o.path)
