@@ -43,12 +43,12 @@ Setting |--auto-filename| will attempt to automatically determine the
 filename from the URL (after any redirections) and used in the
 destination path.
 
-With |--auto-filename-header| in addition, if a specific filename is
+With |--header-filename| in addition, if a specific filename is
 set in HTTP headers, it will be used instead of the name from the URL.
 With |--print-filename| in addition, the resulting file name will be
 printed.
 
-Setting |--no-clobber| will prevent overwriting file on the 
+Setting |--no-clobber| will prevent overwriting file on the
 destination if there is one with the same name.
 
 Setting |--stdout| or making the output file name |-|
@@ -62,9 +62,7 @@ If you can't get |rclone copyurl| to work then here are some things you can try:
 - |--bind 0.0.0.0| rclone will use IPv6 if available - try disabling it
 - |--bind ::0| to disable IPv4
 - |--user agent curl| - some sites have whitelists for curl's user-agent - try that
-- Make sure the site works with |curl| directly
-
-`, "|", "`"),
+- Make sure the site works with |curl| directly`, "|", "`"),
 	Annotations: map[string]string{
 		"versionIntroduced": "v1.43",
 		"groups":            "Important",
