@@ -14,8 +14,7 @@ var completionDefinition = &cobra.Command{
 	Use:   "completion [shell]",
 	Short: `Output completion script for a given shell.`,
 	Long: `Generates a shell completion script for rclone.
-Run with ` + "`--help`" + ` to list the supported shells.
-`,
+Run with ` + "`--help`" + ` to list the supported shells.`,
 	Annotations: map[string]string{
 		"versionIntroduced": "v1.33",
 	},
