@@ -73,16 +73,18 @@ var commandDefinition = &cobra.Command{
 
 For example
 
-    $ rclone tree remote:path
-    /
-    ├── file1
-    ├── file2
-    ├── file3
-    └── subdir
-        ├── file4
-        └── file5
+` + "```text" + `
+$ rclone tree remote:path
+/
+├── file1
+├── file2
+├── file3
+└── subdir
+    ├── file4
+    └── file5
 
-    1 directories, 5 files
+1 directories, 5 files
+` + "```" + `
 
 You can use any of the filtering options with the tree command (e.g.
 ` + "`--include` and `--exclude`" + `.  You can also use ` + "`--fast-list`" + `.
@@ -93,8 +95,7 @@ sizes with ` + "`--size`" + `.  Note that not all of them have
 short options as they conflict with rclone's short options.
 
 For a more interactive navigation of the remote see the
-[ncdu](/commands/rclone_ncdu/) command.
-`,
+[ncdu](/commands/rclone_ncdu/) command.`,
 	Annotations: map[string]string{
 		"versionIntroduced": "v1.38",
 		"groups":            "Filter,Listing",
