@@ -46,6 +46,9 @@ const (
 	// ConfigTokenURL is the config key used to store the token server endpoint
 	ConfigTokenURL = "token_url"
 
+	// ConfigClientCredentials - use OAUTH2 client credentials
+	ConfigClientCredentials = "client_credentials"
+
 	// ConfigEncoding is the config key to change the encoding for a backend
 	ConfigEncoding = "encoding"
 
@@ -383,7 +386,7 @@ func SaveConfig() {
 	ctx := context.Background()
 	ci := fs.GetConfig(ctx)
 	var err error
-	for i := 0; i < ci.LowLevelRetries+1; i++ {
+	for range ci.LowLevelRetries + 1 {
 		if err = LoadedData().Save(); err == nil {
 			return
 		}
@@ -511,6 +514,8 @@ type UpdateRemoteOpt struct {
 	Obscure bool `json:"obscure"`
 	// Treat all passwords as obscured
 	NoObscure bool `json:"noObscure"`
+	// Don't provide any output
+	NoOutput bool `json:"noOutput"`
 	// Don't interact with the user - return questions
 	NonInteractive bool `json:"nonInteractive"`
 	// If set then supply state and result parameters to continue the process
