@@ -1,17 +1,15 @@
-// ReadPassword for OSes which are supported by golang.org/x/crypto/ssh/terminal
+// ReadPassword for OSes which are supported by golang.org/x/term
 // See https://github.com/golang/go/issues/14441 - plan9
-//     https://github.com/golang/go/issues/13085 - solaris
 
-//go:build !solaris && !plan9
-// +build !solaris,!plan9
+//go:build !plan9
 
 package config
 
 import (
 	"fmt"
-	"log"
 	"os"
 
+	"github.com/rclone/rclone/fs"
 	"github.com/rclone/rclone/lib/terminal"
 )
 
@@ -19,12 +17,12 @@ import (
 func ReadPassword() string {
 	stdin := int(os.Stdin.Fd())
 	if !terminal.IsTerminal(stdin) {
-		return ReadLine()
+		return ReadLine("")
 	}
 	line, err := terminal.ReadPassword(stdin)
 	_, _ = fmt.Fprintln(os.Stderr)
 	if err != nil {
-		log.Fatalf("Failed to read password: %v", err)
+		fs.Fatalf(nil, "Failed to read password: %v", err)
 	}
 	return string(line)
 }
