@@ -228,7 +228,7 @@ func rcForget(ctx context.Context, in rc.Params) (out rc.Params, err error) {
 	return out, nil
 }
 
-func getDuration(k string, v interface{}) (time.Duration, error) {
+func getDuration(k string, v any) (time.Duration, error) {
 	s, ok := v.(string)
 	if !ok {
 		return 0, fmt.Errorf("value must be string %q=%v", k, v)
@@ -278,7 +278,7 @@ func getStatus(vfs *VFS, in rc.Params) (out rc.Params, err error) {
 	return rc.Params{
 		"enabled":   vfs.Opt.PollInterval != 0,
 		"supported": vfs.pollChan != nil,
-		"interval": map[string]interface{}{
+		"interval": map[string]any{
 			"raw":     vfs.Opt.PollInterval,
 			"seconds": time.Duration(vfs.Opt.PollInterval) / time.Second,
 			"string":  vfs.Opt.PollInterval.String(),
