@@ -494,7 +494,7 @@ func (item *Item) _createFile(osPath string) (err error) {
 // Open the local file from the object passed in.  Wraps open()
 // to provide recovery from out of space error.
 func (item *Item) Open(o fs.Object) (err error) {
-	for retries := 0; retries < fs.GetConfig(context.TODO()).LowLevelRetries; retries++ {
+	for range fs.GetConfig(context.TODO()).LowLevelRetries {
 		item.preAccess()
 		err = item.open(o)
 		item.postAccess()
@@ -573,6 +573,15 @@ func (item *Item) open(o fs.Object) (err error) {
 	return err
 }
 
+// Calls f with mu unlocked, re-locking mu if a panic is raised
+//
+// mu must be locked when calling this function
+func unlockMutexForCall(mu *sync.Mutex, f func()) {
+	mu.Unlock()
+	defer mu.Lock()
+	f()
+}
+
 // Store stores the local cache file to the remote object, returning
 // the new remote object. objOld is the old object if known.
 //
@@ -589,9 +598,9 @@ func (item *Item) _store(ctx context.Context, storeFn StoreFn) (err error) {
 	// Object has disappeared if cacheObj == nil
 	if cacheObj != nil {
 		o, name := item.o, item.name
-		item.mu.Unlock()
-		o, err := operations.Copy(ctx, item.c.fremote, o, name, cacheObj)
-		item.mu.Lock()
+		unlockMutexForCall(&item.mu, func() {
+			o, err = operations.Copy(ctx, item.c.fremote, o, name, cacheObj)
+		})
 		if err != nil {
 			if errors.Is(err, fs.ErrorCantUploadEmptyFiles) {
 				fs.Errorf(name, "Writeback failed: %v", err)
@@ -728,7 +737,7 @@ func (item *Item) Close(storeFn StoreFn) (err error) {
 			item.c.writeback.SetID(&item.writeBackID)
 			id := item.writeBackID
 			item.mu.Unlock()
-			item.c.writeback.Add(id, item.name, item.modified, func(ctx context.Context) error {
+			item.c.writeback.Add(id, item.name, item.info.Size, item.modified, func(ctx context.Context) error {
 				return item.store(ctx, storeFn)
 			})
 			item.mu.Lock()
@@ -1237,7 +1246,7 @@ func (item *Item) GetModTime() (modTime time.Time, err error) {
 func (item *Item) ReadAt(b []byte, off int64) (n int, err error) {
 	n = 0
 	var expBackOff int
-	for retries := 0; retries < fs.GetConfig(context.TODO()).LowLevelRetries; retries++ {
+	for retries := range fs.GetConfig(context.TODO()).LowLevelRetries {
 		item.preAccess()
 		n, err = item.readAt(b, off)
 		item.postAccess()
